summaryrefslogtreecommitdiffstats
path: root/chrome/common/gfx
diff options
context:
space:
mode:
authorevan@chromium.org <evan@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-01-13 21:35:32 +0000
committerevan@chromium.org <evan@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-01-13 21:35:32 +0000
commit1a14188b1eb6a595da3e2f012e9223ca2b55f590 (patch)
tree2cb98728573b7f3cd5f778b69334a471e3a1a39e /chrome/common/gfx
parent73d00e88fde4c84c583fc9b04a0b2626f9f4b74a (diff)
downloadchromium_src-1a14188b1eb6a595da3e2f012e9223ca2b55f590.zip
chromium_src-1a14188b1eb6a595da3e2f012e9223ca2b55f590.tar.gz
chromium_src-1a14188b1eb6a595da3e2f012e9223ca2b55f590.tar.bz2
Make resource_bundle compile on Linux.
It's still missing implementations of many functions, but those will be easier to implement once we have the data file generation working, which Tony has underway. Review URL: http://codereview.chromium.org/17392 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@7969 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/common/gfx')
-rw-r--r--chrome/common/gfx/chrome_font.h4
-rw-r--r--chrome/common/gfx/chrome_font_skia.cc5
2 files changed, 8 insertions, 1 deletions
diff --git a/chrome/common/gfx/chrome_font_skia.cc b/chrome/common/gfx/chrome_font_skia.cc
index 728893c..1b76a2d 100644
--- a/chrome/common/gfx/chrome_font_skia.cc
+++ b/chrome/common/gfx/chrome_font_skia.cc
@@ -14,6 +14,11 @@ ChromeFont::ChromeFont(const ChromeFont& other) {
CopyChromeFont(other);
}
+ChromeFont& ChromeFont::operator=(const ChromeFont& other) {
+ CopyChromeFont(other);
+ return *this;
+}
+
ChromeFont::ChromeFont(SkTypeface* tf, const std::wstring& font_name,
int font_size, int style)
: typeface_helper_(new SkAutoUnref(tf)),
diff --git a/chrome/common/gfx/chrome_font.h b/chrome/common/gfx/chrome_font.h
index d4cc49f..f4b2a9a 100644
--- a/chrome/common/gfx/chrome_font.h
+++ b/chrome/common/gfx/chrome_font.h
@@ -115,8 +115,10 @@ class ChromeFont {
return dlus * font_ref_->height() / 8;
}
#elif defined(OS_LINUX)
// We need a copy constructor to deal with the Skia reference counting.
ChromeFont(const ChromeFont& other);
+ ChromeFont& operator=(const ChromeFont& other);
// Setup a Skia context to use the current typeface
void PaintSetup(SkPaint* paint) const;
#endif
@@ -115,8 +115,10 @@ class ChromeFont {
}
#elif defined(OS_LINUX)
- // We need a copy constructor to deal with the Skia reference counting.
+ // We need a copy constructor and assignment operator to deal with
+ // the Skia reference counting.
ChromeFont(const ChromeFont& other);